# WFSim
[The XENON waveform simulator.](https://wfsim.readthedocs.io)

## Fax in strax

[![Readthedocs Badge](https://readthedocs.org/projects/wfsim/badge/?version=latest)](https://wfsim.readthedocs.io/en/latest/?badge=latest)
[![Build Status](https://travis-ci.org/XENONnT/WFSim.svg?branch=master)](https://travis-ci.org/XENONnT/WFSim)
[![Coverage Status](https://coveralls.io/repos/github/XENONnT/WFSim/badge.svg?branch=master)](https://coveralls.io/github/XENONnT/WFSim?branch=master)
[![Pytest](https://github.com/XENONnT/WFSim/workflows/Pytest/badge.svg?branch=master)](https://github.com/XENONnT/WFSim/actions?query=workflow%3APytest)
[![CodeFactor](https://www.codefactor.io/repository/github/xenonnt/wfsim/badge)](https://www.codefactor.io/repository/github/xenonnt/wfsim)
[![PyPI version shields.io](https://img.shields.io/pypi/v/wfsim.svg)](https://pypi.python.org/pypi/wfsim/)

Here are the files needed to run the waveform simulator fax and give output in the same formats as used by strax.

## Installation
Follow the [installation guide](https://wfsim.readthedocs.io/en/latest/intro.html) to setup WFSim.

## Examples
Several tutorials are provided in the [tutorial section](https://wfsim.readthedocs.io/en/latest/index.html) linked in the documentation. This code is available as [IPython Notebooks](https://github.com/XENONnT/WFSim/tree/master/notebooks).
